referrerpolicy=no-referrer-when-downgrade

FullClientTransactionPool

Trait FullClientTransactionPool 

pub trait FullClientTransactionPool<Block>: MaintainedTransactionPool<Block = Block, Hash = <Block as BlockT>::Hash, InPoolTransaction = Transaction<<Block as BlockT>::Hash, Arc<<Block as BlockT>::Extrinsic>>, Error = Error> + LocalTransactionPool<Block = Block, Hash = <Block as BlockT>::Hash, Error = Error>
where Block: BlockT,
{ }
FullClientTransactionPool is a trait that combines the functionality of MaintainedTransactionPool and LocalTransactionPool for a given Block.

This trait defines the requirements for a full client transaction pool, ensuring that it can handle transactions submission and maintenance.

The associated types are fully determined by Block, so the client used to build the pool does not appear here.

Implementors

Source

impl<Block, P> FullClientTransactionPool<Block> for P
where Block: BlockT, P: MaintainedTransactionPool<Block = Block, Hash = <Block as BlockT>::Hash, InPoolTransaction = Transaction<<Block as BlockT>::Hash, Arc<<Block as BlockT>::Extrinsic>>, Error = Error> + LocalTransactionPool<Block = Block, Hash = <Block as BlockT>::Hash, Error = Error>,