pub async fn notification_future<Client, Pool, Block>(
client: Arc<Client>,
txpool: Arc<Pool>,
all_block_notifications: bool,
)where
Block: Block,
Client: BlockchainEvents<Block>,
Pool: MaintainedTransactionPool<Block = Block>,Expand description
Inform the transaction pool about imported and finalized blocks.
If all_block_notifications is true, the pool is informed about every imported block (all
forks); otherwise it is only informed about blocks imported as the new best.