pub type TransactionPoolHandle<Block> = dyn FullClientTransactionPool<Block>;Expand description
The public type alias for the trait object providing the implementation of
FullClientTransactionPool for the given Block type.
This handle abstracts away the specific type of the transaction pool, e.g. fork-aware or
single-state. It is unsized, so it is always used behind an Arc.